<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;

class SelectCaixaByLojaFilialMultiple extends CrudWithParameterBag {
    
    protected $dataSourceName = 'select_caixabylojafilialmultiple'; 
    protected $parameterBagColumns = array('CDFILILOJA', 'NRORG', 'TCDFILILOJA');
   
   
    private function setTCDandCDcondition(&$conditions, $key, $keyName) {
        if( !array_key_exists($key, $conditions) ) {
            $conditions['T'.$keyName] = 'T';    
            $conditions[$keyName] = null;    
        } else {
            $conditions[$keyName] = '_'.implode('_', $conditions[$keyName] ).'_';
            $conditions['T'.$keyName] = 'F';
            if($key !== $keyName) {
                unset($conditions[$keyName]);
            }
        }
    }
    
    public function __construct($dataSourceManager, $parameterBag, $utilService ) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response ) {
        
        $conditions = $this->utilService->getParamsAsArray($request);
        $likeableConditions = $this->utilService->getLikeConditions($request);
        
        foreach ($likeableConditions as $condition) {
			if(array_key_exists($condition['columnName'], $conditions)) {
				 unset($conditions[$condition['columnName']]);
			}
			if(array_key_exists(('T'.$condition['columnName']), $conditions)){
			    $conditions['T'.$condition['columnName']] = NULL;
			}
		}
		
        if(array_key_exists('CDFILILOJA', $conditions) && !empty($conditions['CDFILILOJA']) ) {
            $this->setTCDandCDcondition($conditions, 'CDFILILOJA', 'CDFILILOJA');
            $dataSourceFilter = [];
            
            foreach($conditions as $key => $value) {
                $dataSourceFilter[] = $condition = array(
                    "columnName" => $key,
                    "operator"=> "=",
                    "value"=> $value
                );
            }
            
            
            $newRequest = new DTO\Request\Filter (
                new FilterCriteria(
                    $request->getFilterCriteria()->getDataSourceName(),
                    $dataSourceFilter,
                    $request->getFilterCriteria()->getPage(),
                    $request->getFilterCriteria()->getPageSize()
                ),
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            
            foreach ($likeableConditions as $condition) {
                $newRequest->getFilterCriteria()->addCondition($condition['columnName'], $condition['operator'], $condition['value']);
		    }
            parent::find($newRequest, $response);
        }
    }
}